@@ -11,7 +11,10 @@ import re
 
 class Dict(dict):
     def __getattr__(self, item):
-        return self.get(item)
+        try:
+            return super().__getattribute__(item)
+        except AttributeError:
+            return self.get(item)
 
     def to_query_str(self):
         """
